//---------------------------------
//SPI/I2C definitions
//---------------------------------
sbit P3_4=0xB4; // ADD1
sbit P3_5=0xB5; // CLK 
sbit P3_6=0xB6; // SDA
sbit P3_7=0xB7; // ADD0
sbit P2_7=0xA7;	// GPIO
sbit P3_2=0xB2; // To make sure that the INT0 pin on the ADuC841 will be an input.

#define	SDA				P3_7    // SDA on the AD7147
#define	ADD0			P3_6    // ADD0 on the AD7147
#define CLK				P3_5
#define ADD1			P3_4	// ADD1 on the AD7147
#define GPIO			P2_7
#define ADUC841_INT0	P3_2

#define SPICLKPW		1

//---------------------------------
//General definitions
//---------------------------------
#define	BYTE	unsigned char
#define WORD	unsigned int
#define DWORD	unsigned long int

//For the memory map of the ADuC841 registers
#define STAGE_START_ADDRESS		10
#define NB_OF_REGS_PER_STAGE	36
#define NB_OF_CONN_REGS			8


//---------------------------------
//Global variables
//---------------------------------
WORD xdata AD7147Registers[24];	//[0...23 inc]=1st set of registers [0...23 inc]
								//Element[23] = 0x17 = ID register @ 0x17


//---------------------------------
//Function prototypes
//---------------------------------
void ReadFromAD7147(const WORD RegisterStartAddress, const BYTE NumberOfRegisters, WORD *DataBuffer, const WORD OffsetInBuffer);
void WriteToAD7147(const WORD RegisterAddress, const BYTE NumberOfRegisters, WORD *DataBuffer, const BYTE OffsetInBuffer);
BYTE WriteToAD7147ViaI2C(const WORD RegisterStartAddress, const BYTE NumberOfRegistersToWrite, WORD *DataBuffer, const WORD OffsetInBuffer);
BYTE ReadFromAD7147ViaI2C(const WORD RegisterStartAddress, const BYTE NumberOfRegistersToRead, WORD *DataBuffer, const WORD OffsetInBuffer);


//---------------------------------
//Function definitions
//---------------------------------


//---------------------------------
//WriteToAD7147();
//---------------------------------
//This function writes to the AD7147 either via SPI or via I2C, depending 
//on the value of ADIRegisters[8].
//--------------------------------------------------------------------------------
void WriteToAD7147(const WORD RegisterAddress, const BYTE NumberOfRegisters, WORD *DataBuffer, const BYTE OffsetInBuffer)
{
	ADD0=0;
	ADD1=0;
	WriteToAD7147ViaI2C(RegisterAddress, NumberOfRegisters, DataBuffer, OffsetInBuffer);
}

//---------------------------------
//ReadFromAD7147();
//---------------------------------
//This function reads from the AD7147 either via SPI or via I2C, depending 
//on the value of ADIRegisters[8].
//--------------------------------------------------------------------------------
void ReadFromAD7147(const WORD RegisterStartAddress, const BYTE NumberOfRegisters, WORD *DataBuffer, const WORD OffsetInBuffer)
{
	ADD0=0;
	ADD1=0;
	ReadFromAD7147ViaI2C(RegisterStartAddress, NumberOfRegisters, DataBuffer, OffsetInBuffer);
}
